@@ -173,6 +173,8 @@ if __name__ == '__main__':
         with open(cacheDir+"\\"+filename + ".tex", "w", encoding="utf-8") as output:
             output.write(text)
 
+    os.system("cd " + cacheDir)
+    print(os.getcwd()+"\n\n\n")
     os.system("pdflatex -output-directory=" +cacheDir +" "+ cacheDir+ "\\" +filename    + ".tex")
     os.system("move " + cacheDir+"\\"+filename + ".pdf " + invoiceDir)
     win1.close()
